package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@$!`0````````````,``P`!````$!@``#0```!<P0```````#0`(``)
M`"@`'``;``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````B*\`
M`(BO```%`````!````$```"XO0``N,T``+C-``!8`@``G!(```8`````$```
M`@```,2]``#$S0``Q,T```@!```(`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&3`H```P*```,"@``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DN+T`
M`+C-``"XS0``2`(``$@"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`VH(N>%N9WR-XE`YT,*L;W-GC(BT1````3`````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````3````%````!4````50``
M`%L```!<````70```%\```!@`````````&(```!D````90```&8`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"I`@``````
M```````2````5P,`````````````$@```/X!`````````````!(````1````
M```````````@````<`,`````````````$0```-8#`````````````!(```#V
M`@`````````````1````2`,`````````````$@```"4!`````````````!(`
M``#$`@`````````````2````R```````````````$@```)<!````````````
M`!(```"P`@`````````````2````F```````````````$@```"`!````````
M`````!(```!Z`P`````````````2````_0(`````````````$@```!4!````
M`````````!$```!X`@`````````````2````>P$`````````````$@```/<`
M`````````````!$````$`P`````````````2````20$`````````````$@``
M`-8``````````````!(````K`P`````````````B````Q0$`````````````
M$@```$<"`````````````!(```#V`0`````````````2````E`(`````````
M````$@```+(!`````````````!(```"%`@`````````````2````O@$`````
M````````$@```%<!`````````````!(````-`P`````````````2````+0``
M````````````(````%D"`````````````!(```#0`0`````````````1````
M&@,`````````````$@```'@``````````````!(```"B`@`````````````2
M````7@,`````````````$@```.\!`````````````!(```"G````````````
M```2````LP``````````````$@```'`!`````````````!(```!_`@``````
M```````2````9@(`````````````$@```#8!`````````````!(````7`@``
M```````````2````C0(`````````````$@```&H``````````````!(````J
M`0`````````````2````RP(`````````````$@```*<!`````````````!(`
M```$`0`````````````2````4`,`````````````$@```)L"````````````
M`!(```!Q`P`````````````A````B0$`````````````$@```(<`````````
M`````!(````\```````````````@````Z```````````````$@```&<!````
M`````````!(````A`P`````````````2````M@(`````````````$@```%``
M`````````````"````!>`@`````````````2````<@,`````````````$0``
M`.P"`````````````!(````#`@`````````````2````V0(`````````````
M$@```"@"`````````````!(```!O`@`````````````2````Y`(`````````
M````$@```#H#`````````````!(```#?`P``0%\``'L````2``X`K0,``(1@
M````````$@`/``0$``"03@``*0T``!(`#@!K`P``T!4``$`"```2``X`LP,`
M`$!'```%````$@`.`&H$``!01P``'0(``!(`#@!D!```S!$````````2``L`
MEP0``,!;``"``P``$@`.`)(#```0T````````!``&0#K`P``<$D``"(````2
M``X`.`(``)Q@```$````$0`0`)X#``!4X````````!``&0!B!```T$4``#L`
M```2``X`=P0``#!-``!:`0``$@`.`(D$``!P3```>0```!(`#@`1!````-``
M```````0`!@`^`,``*!)``#L````$@`.`(L#```0T````````!``&`!$!```
M#-````0````1`!@`HP,``&!@```"````$@`.`#0$````8```70```!(`#@`7
M!```$!@````````2``X`$P0```#0````````(``8`$X$``"88```!````!$`
M$`#$`P``\$P``#0````2``X`'@0``'!&``#)````$@`.`%4$``"02@``V0$`
M`!(`#@``;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N
M<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`
M7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S
M960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L
M;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`
M7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T
M9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D
M9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<W1A
M8VM?8VAK7V9A:6P`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V9P7VAW`'!A<E]I;FET7V5N
M=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)
M0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N,2XS`$=,
M24)#7S(N-``````"``(``P````(``@`"``(``@`"```````"```````$``(`
M```"```````"```````%````!@`'``(````"``(````(`````@````(````"
M``(`!P`````````"``(````#``(```````@```````(``@`"````````````
M```)``@````"``(`"0`#``D``P`"``(`"``!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``@#?`0``
M$````#`````2:6D-```'`*T$```0````$&EI#0```P"W!`````````$`!@`N
M`@``$``````````2:6D-```)`*T$```0````=!EI"0``"`#!!```$````'(9
M:0D```8`S00``!````!S'VD)```%`-D$```0````%&EI#0``!`#E!```$```
M`!!I:0T```(`MP0```````"XS0``"````+S-```(````[,\```@````$T```
M"`````S0```(````R,\```8$``#,SP``!@<``-#/```&#```U,\```82``#8
MSP``!A4``-S/```&&0``X,\```8C``#DSP``!B4``.C/```&,```\,\```8\
M``#TSP``!CT``/C/```&0@``_,\```9$``#8S@``!P$``-S.```'`@``X,X`
M``<#``#DS@``!P8``.C.```'"```[,X```<)``#PS@``!PH``/3.```'"P``
M^,X```<-``#\S@``!PX```#/```'#P``!,\```<0```(SP``!Q$```S/```'
M$P``$,\```<4```4SP``!Q8``!C/```'%P``',\```<8```@SP``!QH``"3/
M```'&P``*,\```<<```LSP``!QT``##/```''@``-,\```<?```XSP``!R``
M`#S/```'(0``0,\```<B``!$SP``!R0``$C/```')@``3,\```<G``!0SP``
M!R@``%3/```'*0``6,\```<J``!<SP``!RL``&#/```'+```9,\```<M``!H
MSP``!RX``&S/```'+P``<,\```<Q``!TSP``!S(``'C/```',P``?,\```<T
M``"`SP``!S4``(3/```'-@``B,\```<W``",SP``!S@``)#/```'.0``E,\`
M``<[``"8SP``!SX``)S/```'/P``H,\```=```"DSP``!T$``*C/```'0P``
MK,\```=%``"PSP``!T8``+3/```'1P``N,\```=(``"\SP``!TD``,#/```'
M2@``Q,\```=+``!3@^P(Z'L&``"!P_>\``"+@Q0!``"%P'0%Z-X#``"#Q`A;
MPP#_LP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(````
MZ=#_____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'````&@@
M````Z:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C*```
M`&@X````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/____^C
M-````&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I(/__
M__^C0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@```#I
M\/[___^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````:)``
M``#IP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@````
M:*@```#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O___Z-L
M````:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`_O__
M_Z-X````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ````.D0
M_O___Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H``$`
M`.G@_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@```!H
M&`$``.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____HZ0`
M``!H,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]____
MH[````!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``Z3#]
M____H[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP`0``
MZ0#]____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT````&B(
M`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^CW```
M`&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S___^C
MZ````&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I4/S_
M__^C]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z,0`0``9I#_HQ0!
M``!FD(U,)`2#Y/#_<?Q5B>575E-1B<[H:`(``('#Y+@``(/L+(M!!(E%U(M!
M"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z+K]__^+@QP!``"#Q`Q04/^S)`$`
M`.B420``BX,,`0``@\00@#@`#X0F`0``B[L(`0``@^P,_S?H$O___X"(_@(`
M``):_S?H`____X"(_@(```&+!H/$$(/`!3W___\_#X=9`0``@^P,P>`"4.C=
M_/__BWW4BS:#Q!")@W@1``#'@WP1```$````BQ>#_@&)$(V3RI/__XE0!(N3
M0`$``(E0"(V3S9/__XE0#+H!````?A*-="8`BPR7B4R0#(/"`3G6=?*#[`S'
M1+`,`````(/&`VH`4(V#1'?__U90_[.$$0``Z+;]__^#Q""%P(G&#X26````
M@^P,_[.$$0``C7W@Z,C[__^-@W.2__^)^NC[)P``@\00A<`/A(4```"#[`S_
MLX01``#H8OO__^@]_?__@\00B?"+?>1E,ST4````#X6I````C67P65M>7UV-
M8?S#Z+?[__^%P(F#A!$```^$CP```(/L#%#H$/O__XN["`$``%G_-^C2_?__
M@\00QH!Q!0```.FG_O__@^P,_[.$$0``Z&7]__^#Q!")QNE2____BX.`$0``
MA<!T)8/L#%#H>$<``(/$$.E@____4%"-@R.2____LQ@!``!0Z#S\__^-@RB2
M__^)^N@O)P``A<")@X`1```/A#'____KONAJ2```@^P,:@'HH/O__S'M7HGA
M@^3P4%12Z"(```"!PZRV``"-@Y21__]0C8,TD?__4%%6_[,@`0``Z*_[___T
MBQPDPV:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z!<!``"!PF>V``"-BD0!
M``"-@D<!```IR(/X!G87BX+\````A<!T#56)Y8/L%%'_T(/$$,GSPXGVC;PG
M`````.C7````@<(GM@``58V*1`$``(V"1`$``(GE4RG(P?@"@^P$B</!ZQ\!
MV-'X=!2+DBP!``"%TG0*@^P(4%'_TH/$$(M=_,G#B?:-O"<`````58GE4^A7
M____@</3M0``@^P$@+M4`0```'4GBX,0`0``A<!T$8/L#/^S.`$``.B=_/__
M@\00Z#7____&@U0!```!BUW\R<.)]HV\)P````#H-P```('"A[4``(V"]/[_
M_XL(A<EU">E$____C70F`(N2*`$``(72=.U5B>6#[!10_]*#Q!#)Z23___^+
M%"3#55>-:#A64X'L#`,``(E$)$R-1"1XB70D$&6+'10```")G"3\`@``,=N)
M1"0(B7PD%(G!D(UT)@"+5)T`BT2=!,=$V00`````QT39#`````#'1"0$````
M``_*B00DB139B<+!Z!C!Z@B!X@#_```)T(L4)(G'BP0DP>(8P>`("=<E``#_
M``GXB439"(/#`H/[$'6EBT0D"(V4)'@"``")%"2)Q9"-="8`BU5HBT5L@\4(
M,U4X,T4\,U4(,T4,,U7X,T7\QT5\`````(G'B=")T0^L^!\!T0G!B4UX.RPD
M=<B+1"1,BW`,BT@<BU@(BSB+:`2+4!B)="0<B4PD#(MP%(M(((E<)!B+6!")
M;"04B50D"#'2B4PD6(ET)`2)^8G^B1PDBU@D#ZSI&\'F!8E\)!")]8MT)%B)
M7"1<"<T#="1XBWPD7!-\)'R)Z(GQ@<&9>8):B?N#TP`!R(M,)!@1VHL<)(E$
M)"")5"0DBU0D"(G?,=<ASXGZBWPD"(MT)""+1"08QT0D)`````#'1"0T````
M`#'Z`=:+5"0<B<>)="0@B70D*,'G'HG&B?F+?"0(#ZS6`HG-BP0DBU0D)`GU
M`[PD@````(EL)#"+;"0,$ZPDA````(GY@<&9>8):B>N+;"0PB4PD.(/3`(M,
M)#B)7"0\QT0D/``````QQ8M$)!")[R''BT0D((G[BSPDB<8Q^XG'BT0D$`'9
MP>8%B70D.(MT)#B)RP^LUQN+5"04B<$)_@'SP>$>,?\/K-`"B<V+5"0PB5PD
M4`G%B6PD.(ML)"#WU2'JBVPD*"-L)#C'1"0L`````,=$)$0`````B>B)U8M4
M)"0)Q8L$)`.$)(@```")Z<=$)"0`````!9EY@EH!P8G8P>`%B40D*(G8BVPD
M*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<V+5"0X"<6+
M1"0PB6PD0(G=]]4AZHML)%`C;"1`">H#A"20````B=&+5"0L!9EY@EH!P8M$
M)"C!X`6)1"0@BT0D*(ML)"`/K-`;B=J)1"0P"VPD,`'IB?V)WP^L[P+!XAZ)
M3"10B4PD((G5"?V);"0PQT0D-`````"+;"0HBU0D0(MT)#C'1"0\`````/?5
M(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"28````B>F)\`69>8):`<&+1"0@B<N)
MQHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P<=$)"P`````"?X!\\'A'C'_
M#ZS0`HG-BU0D,(E<)&`)Q8M$)$");"0XBVPD(/?5(>J+;"10(VPD.`GJ`X0D
MH````(G1BU0D)`69>8):`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D0`ML)$"+
M1"0@`>F)3"10B4PD*(G!P>$>#ZS0`HG-B=H)Q??2B6PD0"-4)#B+;"1@(VPD
M0(M$)#"+="0XQT0D)`````#'1"1$`````,=$)#0`````">H#A"2H````B=&+
M5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B=J)1"0P"VPD,`'I
MB?V)WP^L[P+!XAZ)3"0@B4PD8(G5BU0D0`G]B6PD,(ML)"CWU2'JBVPD4"-L
M)#")Z(G5BU0D)`G%`[0DL````(GIB?`%F7F"6@'!BT0D((G+B<:)QXM$)"C!
MY@6)="0XBW0D.`^LUQN)P0G^`?/!X1XQ_XE<)%"+5"0LB<W'1"0L`````,=$
M)#P`````QT0D1``````/K-`"BU0D,`G%BT0D0(EL)#B+;"0@]]4AZHML)&`C
M;"0X">H#A"2X````B=&+5"0D!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)
M1"1`"VPD0(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<V)V@G%]](C5"0XB6PD
M0(ML)%`C;"1`BT0D,`GJ`X0DP````(G1BU0D+`69>8):`<&+1"0HP>`%B40D
M((M$)"@/K-`;B=J)1"0PBVPD(`ML)#"+="0XQT0D)`````#'1"0T`````,=$
M)#P``````>F)_8G?#ZSO`L'B'HE,)"")3"10B=6+5"1`"?V);"0PBVPD*/?5
M(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3(````B>F)\`69>8):`<&+1"0@B<N)
MQHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P0G^`?/!X1XQ_P^LT`*)S8M4
M)#")7"1@"<6+1"1`B6PD.(ML)"#WU2'JBVPD4"-L)#@)Z@.$)-````")T069
M>8):`<&)V,'@!8E$)"B)V`^L^!N)1"1`BVPD*`ML)$"+1"0@BU0D),=$)"P`
M````QT0D1`````#'1"0D`````,=$)#0`````BW0D.`'IB4PD*(E,)%")P<'A
M'@^LT`*)S8G:"<7WTB-4)#B);"1`BVPD8"-L)$"+1"0P">H#A"38````B=&+
M5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B=J)1"0P"VPD,`'I
MB?V)WP^L[P+!XAZ)3"1@B4PD((G5BU0D0`G]B6PD,(ML)"CWU2'JBVPD4"-L
M)#")Z(G5"<4#M"3@````BU0D)(GIQT0D/`````#'1"1$`````(GP!9EY@EH!
MP8M$)"")RXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!QT0D+``````)
M_@'SP>$>,?\/K-`"B<V+5"0PB5PD4`G%BT0D0(EL)#B+;"0@]]4AZHML)&`C
M;"0X">H#A"3H````B=&+5"0D!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)
M1"1`"VPD0(M$)"`!Z8E,)&")3"0HB<'!X1X/K-`"B<V)V@G%]](C5"0XB6PD
M0(ML)%`C;"1`BT0D,(MT)#C'1"0D`````,=$)#0`````QT0D/``````)Z@.$
M)/````")T8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)VHE$
M)#`+;"0P`>F)_8G?#ZSO`L'B'HE,)"")3"10B=6+5"1`"?V);"0PBVPD*/?5
M(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3X````B>F)\`69>8):`<&+1"0@B<N)
MQHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P0G^`?/!X1XQ_P^LT`*)S8E<
M)&`)Q8EL)#B+;"0@BU0D,(M$)$#'1"0L`````/?5(>J+;"10(VPD.`GJ`X0D
M``$``(G1BU0D),=$)"0`````!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)
M1"1`"VPD0(M$)"`!Z8E,)"B)3"10B<'!X1X/K-`"B<V)V@G%]](C5"0XB6PD
M((ML)&`C;"0@BT0D,`GJ`X0D"`$``(G1BU0D+`69>8):`<&+1"0HP>`%B40D
M,(M$)"B+;"0P#ZS0&XG:B40D0`ML)$`!Z8G]B=\/K.\"P>(>B4PD8(E,)##'
M1"0T`````(ML)"B)TXM4)"`)^XMT)#B)7"1HB5PD0/?5QT0D1`````#'1"0D
M`````"'JBVPD4"'=B>B)U8M4)#0)Q0.T)!`!``")Z8GP!9EY@EH!P8M$)#")
MRXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!"?X!\\'A'C'_#ZS0`HG-
MBTPD((G>"<4#C"08`0``B5PD4(M<)&B);"0XBU0D-(G(!:'KV6XQZXML)&`Q
MW8GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D*`ML)"B+1"0P`>F)3"1@B4PD
M((G!P>$>#ZS0`HG+BU0D0`G#`Y0D(`$``(ML)%")7"1`QT0D+`````")T(M4
M)"0%H>O9;C-<)#@QW8GSB>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)
M1"0P"VPD,`'IP>(>#ZS[`HG5BY0D*`$``(E,)"@)W8E,)%"+7"1`BTPD.(EL
M)#B!PJ'KV6Z)T(M4)"@!R#'KBVPD8(M,)"@QW8M<)"R)[@'&P>(%BT0D((E4
M)#"+;"0P#ZS9&XM4)"2)\PG-B<$!Z\'A'C'_#ZS0`HG-BXPD,`$``(E<)&`)
MQ8M$)$")WHEL)#"+;"0X@<&AZ]EN`<@S;"0PBU0D+#-L)%#'1"0D`````,=$
M)"P`````B>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"1`"VPD0(M$)"@!Z8E,
M)"")3"10B<'!X1X/K-`"B<N+C"0X`0``BU0D)`G#BT0D.(G=B5PD.(M<)#"!
MP:'KV6X!R#'KBVPD8#'=BYPD0`$``(GI`<&+1"0@P>`%B40D*(M$)""+;"0H
M#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"0HB4PD8`GU@<.AZ]EN
MB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI`<&+1"0HBU0D+(G&B<>+1"0@P>8%
MB70D,(MT)#`/K-<;BU0D),=$)"0`````"?X!\3'_B<Z)3"10B<'!X1X/K-`"
MB<V+C"1(`0``BU0D+`G%BT0D.(EL)#"+;"1`@<&AZ]EN`<@S;"0P,VPD8(GI
M`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D.`ML)#B+1"0H`>F)3"0@B4PD8(G!
MP>$>#ZS0`HG+BXPD4`$``(M4)"0)PXM$)$")W8E<)#B+7"0P@<&AZ]EN`<@Q
MZXML)%`QW8GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XGRB40D0`ML)$"+
MG"18`0``BT0D,,=$)"P``````>G!XAX/K/X"B=6)3"10B4PD*`GU@<.AZ]EN
MBU0D+(GOBVPD.`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D*(G+B<:)QXM$)"#!
MY@6)="0PBW0D,`^LUQN+5"0DB<''1"0D``````G^`?/!X1XQ_P^LT`*)S8N,
M)&`!``"+5"0L"<6+1"0XB=Z);"0PBVPD0('!H>O9;HE<)&`!R#-L)#`S;"10
MB>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"0X"VPD.(M$)"@!Z8E,)%")3"0@
MB<'!X1X/K-`"B<N+C"1H`0``"<.+1"1`BU0D)(E<)#B)W8M<)#"!P:'KV6['
M1"0L``````'(,>N+;"1@,=V+G"1P`0``B>D!P8M$)"#!X`6)1"0HBT0D((ML
M)"@/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)&")3"0H"?6!PZ'K
MV6Z+5"0LB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI`<&+1"0HB<N)QHG'BT0D
M(,'F!8ET)#"+="0P#ZS7&XM4)"2)P0G^`?/!X1XQ_P^LT`*)S8N,)'@!``")
M7"10"<6+1"0XB=Z);"0PBVPD0('!H>O9;@'(,VPD,#-L)&")Z0'!B=C!X`6)
M1"0@B=B+;"0@#ZSX&XM4)"S'1"0D`````(E$)#@+;"0XBT0D*,=$)"P`````
M`>F)3"0@B4PD8(G!P>$>#ZS0`HG+BY0D@`$```G#BT0D0(G=B5PD.(M<)#"!
MPJ'KV6X!T(M4)"0QZXML)%`QW8N<)(@!``")Z0'!BT0D(,'@!8E$)"B+1"0@
MBVPD*`^LT!N)\HE$)$`+;"1`BT0D,`'IP>(>#ZS^`HG5B4PD*(E,)%`)]8'#
MH>O9;HM4)"R)[XML)#@!V(E\)$`Q_8GNBVPD8#'UB>D!P8M$)"B)QHG'P>8%
MB70D,(MT)#`/K-<;"?X!\3'_B4PD8(M$)"")SHM4)"3'1"0D`````(G!P>$>
M#ZS0`HG-BXPDD`$``(M4)"P)Q8M$)#C'1"0L`````(EL)#"+;"1`@<&AZ]EN
M`<@S;"0P,VPD4(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D.`ML)#B+1"0H
M`>F)3"0@B4PD4(G!P>$>#ZS0`HG+BXPDF`$``(M4)"0)PXM$)$")W8E<)#B+
M7"0P@<&AZ]EN`<@QZXML)&`QW8GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0
M&XGRB40D0`ML)$`!Z<'B'@^L_@*)U8E,)&")3"0H"?6+G"2@`0``BT0D,(GO
MBVPD.(M4)"R)?"1`QT0D-`````"!PZ'KV6X!V#']B>Z+;"10,?6)Z8ML)&`!
MP8M$)"B)RXG&B<>+1"0@P>8%B70D,(MT)#`/K-<;BU0D)(G!QT0D)``````)
M_@'SP>$>#ZS0`HG.BY0DJ`$``(M,)$`)QHM$)#B)7"0PB?>)7"10@<*AZ]EN
M`=`Q\8M4)#0QS8GI`<&+1"0PP>`%B40D((M$)#"+;"0@#ZS0&XM4)"R)1"0X
M"VPD.(M$)"@!Z8E,)&")3"0@B<'!X1X/K-`"B<Z+E"2P`0``B?D)QHM$)$")
M?"1HBVPD4(M\)""!PJ'KV6Z)="0XBUPD.`'0,?&+5"0T,<W'1"0L`````,=$
M)#0`````B>F+;"0D`<&)^,'@!8E$)"B)^`^LZ!N+;"0H"<6+1"0P`>F)3"10
MB4PD*(G'B<&+1"1@#ZS7`L'A'HG:B<T)_8G?BUPD+`GO(>J);"1`(?B+?"0D
MB<$)T8M4)"B)SHN,)+@!``"!P=R\&X^)R(M,)&@!R(M,)"@!QL'B!8M$)%")
M5"0PBVPD,`^LV1N)\XMT)"`)S0'KB?&)7"0PB5PD8`^L_@+!X1Z+7"1`B<^+
M3"0X"?>)^HE\)%`)VB'0B?HAVHG%"=6+E"3``0``B>Z!PMR\&X^)T(M4)#`!
MR`'&P>(%B50D((M,)#"+7"0TBVPD((M\)"R+1"1@QT0D)`````#'1"0L````
M``^LV1N)\XMT)"@)S0'KB?&)7"0@B5PD:`^L_@*+?"10P>$>B<N+3"1`"?.)
M^HE<)#@)VB'0B?HAVHG%BUPD)`G5BY0DR`$``(GN@<+<O!N/B="+5"0@`<B+
M3"0@`<:+1"1HP>(%B?>+="0PB50D*(ML)"@/K-D;BUPD.(N4)-`!```)S8GQ
M`>_!X1Z)?"0HB7PD8(G-BWPD-(G9#ZS^`@GU">DAZXEL)$`AR(G!"=F!PMR\
M&X^+7"0LB<Z+3"10B="+5"0H`<B+3"0H`<;!X@6)5"0PBVPD,`^LV1N)\XMT
M)""+?"0D"<V+1"1@QT0D-``````!Z\=$)"0`````B?&)7"1HB5PD,`^L_@+!
MX1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?J+?"0L(=J)Q8M<)#0)U8N4)-@!
M``")[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D:,'B!8E4)""+;"0@#ZS9&XGS
MBW0D*`G-`>N)\8E<)"")7"1@#ZS^`HM\)%#!X1Z)RXM,)$`)\XGZB5PD.`G:
M(=")^B':B<6+7"0D"=6+E"3@`0``B>Z!PMR\&X^)T(M4)"`!R(M,)"`!QL'B
M!8GWB50D*(ML)"@/K-D;"<T![XE\)&B)?"0HBW0D,(M\)#2+7"0XBT0D8(N4
M).@!``#'1"0L`````(GQQT0D-``````/K/X"P>$>BWPD),=$)"0`````B<V)
MV0GU">DAZXEL)$`AR(G!"=F!PMR\&X^+7"0LB<Z+3"10B="+5"0H`<B+3"0H
M`<;!X@6+1"1HB50D,(ML)#`/K-D;B?.+="0@"<T!ZXGQB5PD,(E<)&`/K/X"
MP>$>BUPD0(G/BTPD.`GWB?J)?"10"=HAT(GZ(=J)Q8M<)#0)U8N4)/`!``")
M[H'"W+P;CXG0BU0D,`'(BTPD,`'&P>(%B50D((ML)"`/K-D;B?.+="0H"<T!
MZXE<)&B)7"0@B?&+?"0LP>$>BT0D8(G+BTPD0,=$)"P`````#ZS^`HM\)%`)
M\XE<)#B)^@G:(=")^B':B<6+7"0D"=6+E"3X`0``B>Z!PMR\&X^)T(M4)"`!
MR(M,)"`!QHM$)&C!X@6)]XMT)#")5"0HBVPD*`^LV1N+7"0XBY0D``(```G-
MB?$![\'A'HE\)"B)?"1@B<V+?"0TB=G'1"0T``````^L_@*+?"0D"?4)Z2'K
MB6PD0"'(B<$)V8'"W+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,)"@!QL'B!8E4
M)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)&B)7"0P#ZS^`L'A'HM<)$"+1"1@
MB<^+3"0XQT0D)``````)]XGZB7PD4`G:(=")^HM\)"PAVHG%BUPD-`G5BY0D
M"`(``,=$)"P`````B>Z!PMR\&X^)T(M4)#`!R(M,)#`!QHM$)&C!X@6)5"0@
MBVPD(`^LV1N)\XMT)"@)S0'KB?&)7"0@B5PD8`^L_@*+?"10P>$>B<N+3"1`
M"?.)^HE<)#@)VB'0B?HAVHG%BUPD)`G5BY0D$`(``(GN@<+<O!N/B="+5"0@
M`<B+3"0@`<:+1"1@P>(%B?>+="0PB50D*(ML)"@/K-D;BUPD.`G-B?$![\'A
M'HE\)&B)?"0HB<V+?"0TB=D/K/X""?4)Z2'KB6PD0"'(BY0D&`(``(M\)"2)
MP<=$)#0`````QT0D)``````)V8M<)"R)SHM,)%"!PMR\&X^)T(M4)"@!R(M,
M)"@!QL'B!8M$)&B)5"0PBVPD,`^LV1N)\XMT)"`)S0'KB?&)7"0PB5PD8`^L
M_@+!X1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?J+?"0L(=J)Q8M<)#0)U8N4
M)"`"``")[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D8,'B!8E4)""+;"0@#ZS9
M&XGSBW0D*`G-`>N)\8E<)&B)7"0@#ZS^`HM\)%#!X1Z)RXM,)$`)\XGZB5PD
M.`G:(=")^B':B<4)U8N4)"@"``")[H'"W+P;CXG0BU0D((M<)"0!R(M,)"#'
M1"0L``````'&BT0D:,'B!8GWBW0D,(E4)"B+;"0H#ZS9&XM<)#B+E"0P`@``
M"<V)\0'OP>$>B7PD*(E\)&")S8M\)#2)V<=$)#0`````#ZS^`HM\)"0)]0GI
M(>N);"1`(<B)P0G9@<+<O!N/BUPD+(G.BTPD4(G0BU0D*`'(BTPD*`'&P>(%
MBT0D8(E4)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)#")7"1H#ZS^`L'A'HM<
M)$")SXM,)#@)]XGZB7PD4`G:(=")^B':B<4)U8N4)#@"``")[H'"W+P;CXG0
MBU0D,`'(`<;!X@6)5"0@BTPD,(M<)#2+;"0@BWPD+(M$)&C'1"0D`````,=$
M)"P`````#ZS9&XGSBW0D*`G-`>N)\8E<)"")7"1@#ZS^`HM\)%#!X1Z)RXM,
M)$`)\XGZB5PD.`G:(=")^B':B<6+7"0D"=6+E"1``@``B>Z!PMR\&X^)T(M4
M)"`!R(M,)"`!QHM$)&#!X@6)]XMT)#")5"0HBVPD*`^LV1N+7"0XBY0D2`(`
M``G-B?$![\'A'HE\)"B)?"1HB<V+?"0TB=D/K/X""?4)Z2'KB6PD0"'(B<$)
MV8'"W+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,)"@!QL'B!8E4)#"+;"0P#ZS9
M&XGSBW0D((M\)"0)S8M$)&C'1"0T``````'KQT0D)`````")\8E<)#")7"1@
M#ZS^`L'A'HM<)$")SXN,)%0"```)]XGZB7PD4`G:(=")^C'_(=J)Q0G5BY0D
M4`(``(GN@<+<O!N/@]$`B=`QVXG*BTPD.`'(BTPD,!':`<:+7"0T$=>+5"0P
M#ZS9&\'B!8GSB?Z)5"0@BVPD(#'2BWPD+`G-`>N+;"10$=:+E"18`@``B5PD
M((ET)&R+="0HB5PD:(M<)"2)\0^L_@+!X1Z)\(G.BTPD0`G&@<+6P6+*B="+
M5"0@B70D.`'(,?6)Z8ML)&`QS8M,)"")[@'&P>(%B50D*(ML)"@/K-D;BWPD
M,(GSBY0D8`(```G-QT0D+``````!ZXML)#3'1"0T`````(GYB5PD8(E<)"C!
MX1Z+7"1H#ZSO`HG-BTPD4`G]@<+6P6+*BWPD)(G0BU0D*(EL)$`!R(M,)#@Q
MZ3'+BTPD*(G>BUPD+`'&P>(%BT0D.(E4)#"+;"0P#ZS9&XGSBW0D((M4)#0)
MS0'KBVPD8(GQB5PD,(E<)%#!X1Z+7"1`#ZS^`HG/BXPD:`(```GWB7PD.('!
MUL%BR@'(,?LQW8GI`<&+1"0PB<N)Q@^LT!O!Y@6)1"0@BVPD(`GU`>N)7"1@
MB5PD(,=$)"0`````BW0D*(M\)"R+;"0XBT0D0(M4)"2)\<=$)"P`````#ZS^
M`L'A'@GQB<Z+C"1P`@``B70D0('!UL%BR@'(,?6)[HML)%`Q]8GI`<&+1"0@
MB<?!YP6)?"0HB<>+="0H#ZS7&XM$)#"+5"0T"?X!\3'_B<Z)3"10B<'!X1X/
MK-`"B<V+E"1X`@``"<6+1"0XB6PD,(ML)$"!PM;!8LH!T#-L)#"+5"0D,VPD
M8(GI`<&)\,'@!8E$)"B)\(ML)"@/K/@;B40D.`ML)#B+1"0@`>F)3"1@B4PD
M*(G!P>$>#ZS0`HG+BXPD@`(```G#BT0D0(G=B5PD.(M<)#"!P=;!8LJ+5"0L
MQT0D)``````!R#'KBVPD4#'=BYPDB`(``(GI`<&+1"0HP>`%B40D((M$)"B+
M;"0@#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"10B4PD(`GU@</6
MP6+*BU0D)(GOBVPD.`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D((G+B<:)QXM$
M)"C!Y@6)="0PBW0D,`^LUQN+5"0LB<$)_@'SP>$>,?\/K-`"B<V+C"20`@``
MB5PD8`G%BT0D.(G>B6PD,(ML)$"!P=;!8LH!R#-L)#`S;"10B>D!P8G8P>`%
MB40D*(G8#ZSX&XE$)#B+;"0H"VPD.(M$)""+5"0DQT0D+`````#'1"0D````
M``'IB4PD4(E,)"B)P<'A'@^LT`*)RXN,))@"``"+5"0L"<.+1"1`B=V)7"0X
MBUPD,('!UL%BR@'(,>N+;"1@,=V+G"2@`@``B>D!P8M$)"C!X`6)1"0@BT0D
M*(ML)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)"")3"1@"?6!
MP];!8LJ+5"0DB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI`<&+1"0@B<N)QHG'
MP>8%B70D,(MT)#`/K-<;"?X!\S'_B5PD4(M$)"B)WHM4)"S'1"0L`````(G!
MP>$>#ZS0`HG-BXPDJ`(``(M4)"0)Q8M$)#C'1"0D`````(EL)#"+;"1`@<'6
MP6+*`<@S;"0P,VPD8(GI`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D.`ML)#B+
M1"0@`>F)3"0HB4PD8(G!P>$>#ZS0`HG+BY0DL`(```G#BT0D0(G=B5PD.(M<
M)#"!PM;!8LH!T(M4)"PQZXML)%`QW8GI`<&+1"0HP>`%B40D((M$)"B+;"0@
M#ZS0&XGRB40D0`ML)$`!Z<'B'@^L_@*)U8E,)%")3"0@"?6+G"2X`@``BT0D
M,(GOBVPD.(M4)"2)?"1`@</6P6+*`=@Q_8GNBVPD8#'UB>D!P8M$)"")RXG&
MB<>+1"0HP>8%B70D,(MT)#`/K-<;BU0D+(G!QT0D+``````)_@'SP>$>,?\/
MK-`"B<V+C"3``@``BU0D)`G%BT0D.(E<)&");"0PBVPD0(G>@<'6P6+*`<@S
M;"0P,VPD4(GI`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D.`ML)#B+1"0@`>F)
M3"10B4PD*(G!P>$>#ZS0`HG+BY0DR`(```G#BT0D0(G=B5PD.(M<)#"!PM;!
M8LH!T#'KBVPD8#'=B>D!P8M$)"B+5"0LBYPDT`(``,=$)"0`````P>`%B40D
M((M$)"B+;"0@#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"1@BU0D
M)`GU@</6P6+*B4PD((GOBVPD.`'8B7PD0#']B=>)[HML)%`Q]8GI`<&+1"0@
MB<L/I,<%B<;!Y@6)?"0TB<>)="0PBT0D*(MT)#`/K-<;BU0D+(G!"?X!\\'A
M'C'_#ZS0`HG-BXPDV`(``(G>"<6)7"10BT0D.(N<)-P"``");"0P@<'6P6+*
MBVPD0(/3`#'2`<@1VC-L)#`QVS-L)&")Z0'!B?`1T\'@!3'2B40D*(GP#ZSX
M&XE$)#B+;"0H"VPD.(M$)"#'1"0L``````'I$=.+5"0DB4PD*(E,)&")P8E<
M)&3!X1['1"0D``````^LT`*)RXN4).`"```)PXM$)$")W8E<)#B+7"0P@<+6
MP6+*`="+5"0L,>N+;"10,=V+G"3H`@``B>D!P8M$)"C!X`6)1"0@BT0D*(ML
M)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)""+5"0D"?6!P];!
M8LJ)3"1`B>^+;"0X`=B)?"0P,?V)UXGNBVPD8#'UB>D!P8M$)"`/I,<%B<;!
MY@6)?"14B<>)="10BW0D4`^LUQN+5"0L"?Z)\`'(,?^)QHM$)"B)P<'A'@^L
MT`*)S8M4)"0)Q8M$)"");"10B=.)P0^DRQ[!X1Z)3"0@B=&)P@^LR@+!Z0*+
M1"0XB5PD)(E,)"R+C"3P`@``BUPD,(E4)"B)^H'!UL%BR@'(,>N+;"1`,=V)
MZ0'!B?#!X`6)1"0XB?"+;"0X#ZSX&P^D\@6)1"1`"VPD0(E4)#R)^L'J&XE4
M)$2+5"1,B>B+;"0@`<B)P8M$)!@#3"00QT($`````,="#``````!\`ML)"B)
M0@B)"HGH`P0DB4(0BT0D4`-$)`C'0A0`````QT(<`````,=")`````")0AB+
M1"0P`T0D6(E"((N$)/P"``!E,P44````=0N!Q`P#``!;7E]=P^A8(0``D(VT
M)@````!55U93Z"?9__^!PZ./``"#[!R%P`^$JP```(N+,`$``(L)A<F)3"0(
M#X27````#[8(A,ET:X#Y/71FB<:#Q@$/M@Z$R70%@/D]=?$IQHM,)`B+*87M
M=#:)5"0,B40D!(G/C;0F`````(/L!%;_="0,5>BJU?__@\00A<!U!X!\-0`]
M="2#QP2++X7M==N#Q!R)Z%M>7UW#B?:-O"<`````,?;KJ8UT)@")^BM4)`B+
M1"0,C6PU`<'Z`HD0@\0<B>A;7E]=PS'MZ\2-M"8`````5U:)QE/H@MG__X'"
MTHX``(/L$(NZ,`$``(U<)`AEH10```")1"0,,<")VHGPZ/[^__^%P'0[C78`
MC;PG`````(M4)`B+!XT$D(M0!(72B1!TUXVV`````(/`!(M0!(72B1!U](G:
MB?#HP_[__X7`=<^+1"0,93,%%````'4'@\006UY?P^CV'P``C;8`````55>)
MQ593B=;HP]?__X'#/XX``(/L.&6A%````(E$)"@QP#'`@#H]#Y3``<96Z"[3
M__^#Q!")!"2)Z(U4)!CH7?[__X7`#X0-`0``@^P,B<=0Z`K3__^#Q!`Y!"0/
MAMX```"+1"08C0R%`````(N#,`$``(E$)`0/MD4`A,`/A)P!```\/0^$E`$`
M`(GHZP:0@/H]=`J#P`$/MA"$TG7Q*>B+5"0$@^P,BSH!SXM,)`R-1`@"4.A&
MTO__@\00A<")!P^$:P$``(M4)`2-30&+`HM4)!B+%)`/MD4`/#V(`G0CA,!U
M#^L=B?:-O"<`````/#UT$(/!`0^V0?^#P@&$P(@"=>S&`CTQP(VT)@`````/
MM@P&B$P"`8/``83)=?$QP(M<)!QE,QT4````#X4*`0``@\0L6UY?7<.-M@``
M``"#Q@$/MD;_@\<!A,"(1_]U[^O,D(UT)@"+@S`!``"+$(E$)`2+.H7_#X2X
M````,<#K"(VV`````(GXC7@!BPRZA<EU](T$A0P```"+BW01``"%R70[@^P(
M4%+H4='__XM,)!2#Q!"%P(D!#X2"````C0R]`````(E$)`B+1"0(QT2X!```
M``")?"08Z:?^__^)5"0(@^P,QX-T$0```0```%#H&='__X/$$(7`=$2-#+T`
M````@^P$48M4)!")3"044HE$)!10Z+3/__^+3"04BT0D&(/$$(D!BTPD#.N<
M,<#I>_[__[@(````,?_I6?___[C_____Z>7^___HKQT``.L-D)"0D)"0D)"0
MD)"0D%575E.)QNAUU?__@</QBP``@>R,````9:$4````B40D?#'`A?9T!8`^
M`'4DBT0D?&4S!10````/A40!``"!Q(P```!;7E]=PY"-M"8`````@^P,5NAW
MTO__@\00A<")QW3*C8/4D?__B40D"(U$)!R)1"0,C70F`(/L#%?HS]'__X/$
M$(7`B<4/A,H````/ME43N"X```")P2G1=1L/ME44A=)TTRG0#X2;````]]B%
MP'3%ZP>-=@"%R72\@^P,5NA+T/__C543B40D%(D4)(E4)!#H.-#__XM,)!2-
M1`$"B00DZ,C/__^)Q5A:BU0D"%)6_W0D&&K_:@%5Z.#1__^#Q!S_="0056H#
MZ''1__^#Q!"#^/]T$(M$)"PE`/```#T`0```=%&#[`Q5Z-#.__^#Q!"#[`Q5
MZ$3.__^#Q!#I-/___XUT)@`/MD45Z5[___^-M"8`````@^P,5^A?T?__B30D
MZ$?.__^#Q!#IN_[__XVT)@````")Z.B!_O__Z[+H&AP``(UV`(V\)P````!7
M5HG'4^CFT___@<-BB@``@^P,B[,(`0``_S;HX-#__X/$#`4\`0``4%=J`^C?
MT/__@\00A<!T"%LQP%Y?PV:0@^P,_S;HMM#__XN`3`$``(/$$"4`\```/0!`
M``!T'X/L#/\VZ)?0__^+@$P!``"#Q!`E`/```#T`H```=;J#[`AJ`E?HY\__
M_X/$$(7`#Y3`6P^VP%Y?PY"-M"8`````55>)QU93Z$73__^!P\&)``"![#`0
M``!EH10```")A"0@$```,<")5"00:/\/``"-@]J1__^-="0D5E#HL,W__X/$
M$(7`?F&-:/^`?"P<`'1/B<6#[`15:B]6Z!'/__^#Q!"%P'1"BX,(`0``@^P,
M_S#HZL___U565U#H@<___X/$((N$)!P0``!E,P44````=3F!Q"P0``!;7E]=
MPXUV`(7M=:^-="8`BX,(`0``@^P,_S#HJ,___X/$#/]T)!!74.@ZS?__@\00
MZ[?HH!H``%/H>M+__X'#]H@``(/L%(N#"`$``/\PZ'3/__^-D_23__]2C9/I
MD?___[,$`0``4E#H*L[__X/$*%O#D(UT)@!64^@YTO__@<.UB```@^P0B[,(
M`0``_S;H,\___XD$).B;____6/\VZ"//__]:C9.ID___66H`4E*-D_2,__]2
MC9,%DO__4E#H8\[__X/$)%M>PXVV`````(V\)P````!55U93Z-?1__^!PU.(
M``"![!P@``!EH10```")A"0,(```,<#HM\S__XV3Y9'__X/L"%)0C8,:DO__
M4&@!$```:@&-="0F5NCTSO__@\0@A<!X;8/L!&@`$```C;PD$Q```%=6Z!?,
M__^#Q!"%P(G%>$Z-0`&#[`Q0Z)+,__^#Q!"%P(G&=!*#[`155U#H7LO__\8$
M+@"#Q!"+C"0,(```93,-%````(GP=1F!Q!P@``!;7E]=PXUV`(V\)P`````Q
M]NO5Z#<9``"-M"8`````Z2O___^-="8`C;PG`````%575E/H]]#__X'#<X<`
M`('L+!```(N$)$`0``"-5"08B[0D1!```(D$)(G'9:$4````B80D'!```#'`
MC8,HDO__Z(KW__^#[`B)Q6HO5^@=S/__@\00A<!T,8L\)(V#,9+__XGZZ,;X
M__^)^(N4)!P0``!E,Q44````#X68`0``@<0L$```6UY?7<.#[`S_="0,Z/G+
M__]:68G'C8,^DO__B40D#%!6Z.3,__^)QHU'`8/$$(E$)`B+@P@!``")1"0,
MC;8`````A?9TCH`^``^$VP```(7M=!6#[`A65>C=R?__@\00A<`/A*,```"#
M[`Q6Z)G+__^#Q!"`?`;_+W45C;0F`````(/H`8!\!O\OQ@0&`'3R`T0D"#W_
M#P``#X\U____C8-`DO__@^P$_W0D!%"-@V23__]64&@`$```:@&-="0X5N@4
MS?__@\04BWPD&/\WZ+;,__^#Q`P%/`$``%!6:@/HE<S__X/$$(7`=1^#[`S_
M-^B4S/__BX!,`0``@\00)0#P```]`(```'17@^P(_W0D#&H`Z/'+__^#Q!")
MQND?____C;0F`````(7M="2-@R:2__^Y`@```(GNB<?SIG3*B<:X`0```.E#
M____D(UT)@"-LR:2__^X`0```.DN____@^P(:@%6Z(W+__^#Q!"%P'67C8,Q
MDO__B?+H*??__X/L#%;H\,K__X/$$.E4_O__Z`,7``"-=@"+1"0$#[8(A,ET
M%8U0`6:0@/DO#[8*#T3"@\(!A,EU\//#C;0F`````(V\)P````!64^BISO__
M@<,EA0``@^P4BW0D((7V=%`/MA:$TG1)B%0D#X/L#%;H%,K__XU$!O^#Q!`/
MME0D#SG&<@OK'F:0@^@!.<9T&8`X+W3TZP=FD(`X+W1`@^@!.<9R]#G&=36`
M^B]U<XUV`(/L#&H"Z&[)__^#Q!"%P'17NBX```!FB1"#Q!1;7L.)]HV\)P``
M``"`."]U!X/H`3G&<O0I\(U0`H'Z`!```'<G@\`!:``0``!05HVS=`$``%;H
M0<K__X/$$(GP@\046U[#C;8`````@\04,<!;7L.-@T"2__^#[`Q0Z,G)__^#
MQ!#KE8UT)@!75E/HN,W__X'#-(0``(/L,&6A%````(E$)"PQP(N#T)/__XUT
M)`2)1"0*BX/4D___B40D#HN#V)/__XE$)!*+@]R3__^)1"06BX/@D___B40D
M&HN#Y)/__XE$)!Z+@^B3__^)1"0BBX/LD___B40D)@^W@_"3__]FB40D*HV#
M0I+__^C8]/__C8-+DO__Z,WT__^-@U.2___HPO3__XV#7)+__^BW]/__C8-C
MDO__Z*ST__^-@W.2___HH?3__XV#*)+__^B6]/__C8-_DO__Z(OT__^-@XF2
M___H@/3__XV#DY+__^AU]/__C8,QDO__Z&KT__^-@YV2___H7_3__XV#II+_
M_^A4]/__C8.QDO__B?+H=_/__X7`=`V)PHV#B9+__^C&]/__C8/"DO__B?+H
M6?/__X7`=`V)PHV#U)+__^BH]/__C8/?DO__B?+H._/__X7`=#>)PHV#*)+_
M_^B*]/__C9,+D___C8-CDO__Z'GT__^+1"0L93,%%````'50@\0P6UY?PY"-
M="8`C8/ODO__B?+H\_+__X7`=`^)PHV#?Y+__^A"]/__Z[:-="0;C;L`D___
MN0H```#SIG6CC50D)8V#?Y+__^@>]/__ZY+H!Q0``(VT)@````!3Z-K+__^!
MPU:"``"#[!AEH10```")1"0,,<"+@SP!``"#^/]T&HM,)`QE,PT4````=4&#
MQ!A;PY"-M"8`````C50D"(V#?Y+__^AA\O__A<!T'0^V$(#Z,`^5P(32#Y7"
M(=`/ML")@SP!``#KN&:0,<#K[^B'$P``C;0F`````%/H6LO__X'#UH$``(/L
M".B\Q?__@^P,4.@CQ?__@\00A<!T#(L`@\0(6\.0C70F`#'`Z_*-M@````"-
MOP````!55U93Z!?+__^!PY.!``"#[%R+1"1PC;L7D___C;,-D___QT0D2```
M``"-;"0PB7PD,(ET)#2)1"0(9:$4````B40D3#'`C8,:D___B40D.(V#$)/_
M_XE$)#R-@Q63__^)1"1`C8,GD___B40D1(U$)"R)1"0,C8,^DO__B40D%(V#
M9)/__XE$)!CK*(UT)@"#[`C_="004(E$)"#H+\3__X/$$(7`=$B#Q02%]G0K
MB?>+=02+5"0,B?CH,?'__X7`=`6`.`!UR(M4)`B)^(/%!.AZ\O__A?9UU8M$
M)$QE,P44````=6Z#Q%Q;7E]=PY"#[`S_="04Z+3%__^+3"0@B40D+(D,)(E,
M)"#HH,7__XM4)"R-1`("B00DZ##%__^#Q`R+3"044?]T)!S_="04_W0D*&K_
M:@%0B40D,.@^Q___@\0@BU0D$(GXZ`#R___I4____^CF$0``C;8`````55=6
M4^@B$0``@<4S@```@>P\@0``BX0D4($``(U4)#R-G3*3___'1"1(`````,=$
M)&P`````B5PD3,=$)%0`````B40D'(E4)!1EH10```")A"0L@0``,<"-A3Z3
M__^)1"1`C84FDO__B40D1(V%U)+__XE$)`R)1"18C87-DO__B40D7(V%0Y/_
M_XE$)&"-A>J2__^)1"1DC85+D___B40D:(V%3Y/__XE$)%"-A2B2___HV.__
M_X7`=`F`.``/A7L$``#HEOW__X7`B<8/A),$``"#[`R)ZU;H<<3__XU$``&)
M!"3H!<3__XE$)""#Q!"`/@!T-HV%6)/__XM\)!")!"2-="8`#[8&@^P,B>N#
MQ@%0_W0D$&K_:@%7@\<"Z/O%__^#Q""`/@!UVXU<)%B+1"0,BWPD%.L.D(UT
M)@"#PP2+`X7`="^)^NA`[___A<")QG3J@#@`=.7H</3__X7`=-R#[`R)ZU;H
M4<3__X/$$(7`B<=U0HM<)$`Q]NL+@\8!BURT0(7;="V`.P!T*(G8Z#GT__^%
MP'3E@^P,4XGKZ!K$__^#Q!"%P'33B<?K"8VT)@`````Q_X/L#(GK5^B+P___
M@\00BTPD$(L9@\$$C9/__O[^]],AVH'B@("`@'3IB=/!ZQ#WPH"````/1-.-
M60(/1,N)TP#3B>N#V0,K3"00@^P,C;0!!`0``%;HW,+__XE$)!R)P8V%79/_
M__]T)"!0C85`DO__B40D*%"-A6*3__]7B<]0:O]J`5'HW,3__X/$*&C``0``
M5^A>P___@\00@_C_#X22````B[T(`0``@^P,B>O_-^A@Q/__@\0,!3P!``!0
M_W0D%&H#Z%S$__^)1"0P@\00A<`/A*4```"#[`R)Z_]T)!B+1"0L_S"-A3R4
M__]0BX4``0``:@'_,.CHP___@\0@QT0D&`````"+C"0L@0``93,-%````(M$
M)!@/A4D*``"!Q#R!``!;7E]=PXUV`(V\)P````#HV\+__XL`@_@1#X1>____
M@^P(4/]T)!B+1"0L_S"-A0"4__]0BX4``0``:@'_,.A\P___@\0@QT0D&```
M``#KDHVT)@````"#[`S_-^B.P___BX!,`0``@\00)0#P```]`$````^%./__
M_X/L#/\WZ&O#__^+@%0!``")1"00Z+S`__^#Q!`Y!"0/A1/___^#[`S_-^A&
MP___BX!,`0``@\00)?\!```]P`$```^%\/[__X/L#(GK5NA"P?__BU0D)(E$
M)"B-A1"3___HS^S__X/$$(7`#X0$`@``@^P,B>M0Z.G!__]:65"+1"0H_S#H
MV_3__XE$)!"#Q!"%P`^$W`$``(/L#(GKBWPD#%?H3<'__X/$$(/X`WXMC70'
M_(G[C;UKD___N04```#SIG48@_@$#X2F!P``@'P#^R\/A)L'``"-="8`Z*/Y
M__^%P'4?@^P(B>MJ`/]T)`SH'\'__XE$)"R#Q!"%P`^%?@$``(V5"Y/__XVU
MJ9/__XV%?Y+__XGKC;V2D___Z''M___H/,#__U90C86$D____W0D&/]T)!A0
M:O]J`?]T)#3H?L+__X/$((DT)(E\)!2+="0@BWPD&.M`C78`C;PG`````.@+
MP?__@S@1=42)ZX/&`>CLO___@^P,_W0D#%90_W0D*/]T)"C_="0T:O]J`5?H
M+<+__X/$,(/L"(GK:,`!``!7Z*K`__^#Q!"#^/]TLH/L#(GK_W0D&.BDOO__
MBWPD*(V%*)+__XGZZ,/L__^)/"3H:_G__X/$$.F&_?__C78`@^P,B>M0B40D
M$.A1^?__BT0D$(D$).AEP/__B40D*(/$$.E<_?__OP$```")V(MT)!3K#XUT
M)@"+1+Q,@\<!A<!T*8GRZ`;K__^%P'3J@#@`=.6#[`R)ZU#H(L#__X/$$(7`
M=-.)QNDH^___@^P,B>N-M3>3__]J#>@RO___B40D((/$$.DM^___C;8`````
MBT0D'(L`B00DZ1;^__]J`FK_:NZ+?"0H5^C"OO__@\0,:@:-A"0T`0``B40D
M'%!7Z(N]__^#Q!"`O"0L`0```'4.@+PD+0$``$,/A&\&``!J`&H`B>MJ`/]T
M)"CH?[[__\>$)(`````!(T5GQX0DA`````````#'A"2(````B:O-[\>$)(P`
M````````QX0DD````/[<NIC'A"24`````````,>$))@```!V5#(0QX0DG```
M``````#'A"2@````\.'2P\>$)*0`````````QX0DJ`````````#'A"2L````
M`````,>$)+``````````QX0DM`````````#'A"3X`````````(/$$(U$)'")
M+"2)1"0LC80DJ````(E$)""0@^P$:`"```#_="0<_W0D*(M<)!#HA[S__X/$
M$(7`B<8/C@L"``"+C"28````BYPDG````(GPB?7!X`.)]\']'P'(@_L`#X?-
M`0``.<$/A\4!``"+C"2@````BYPDI````(F$))@```")^(GJ#ZSH'<'J'<>$
M))P``````````<B)A"2@````BX0DZ````!':B90DI````(7`#X1I`0``OT``
M```IQSG^#T[^`T0D((/L!%?_="0<4(M<)!#H'[S__XN$)/@````!^(F$)/@`
M``"#Q!"#^$`/A2/___^+1"0L*?X#?"04Z!3#__^-="8`@_X_#X[H````C4;`
MBVPD+(G^B40D*,'H!HU8`8E$)"3!XP8!^XUV`(L&@\9`B80DJ````(M&Q(F$
M)*P```"+1LB)A"2P````BT;,B80DM````(M&T(F$)+@```"+1M2)A"2\````
MBT;8B80DP````(M&W(F$),0```"+1N")A"3(````BT;DB80DS````(M&Z(F$
M)-````"+1NR)A"34````BT;PB80DV````(M&](F$)-P```"+1OB)A"3@````
MBT;\B80DY````(GHZ#_"__\Y\P^%3____XM,)"B)R(/@P(U\!T"+1"0DP>`&
M*<&)SFI$5E?_="0LBUPD$.@NO/__B;0D^````(/$$.G__?__C;0F`````(M\
M)!3IW_[__XVT)@````"+C"2@````BYPDI````(/!`8/3`.DP_O__BRPD@^P,
M_W0D*(GKZ+Z]__^+A"2P````BYPDJ````(NT)*P```"+E"2T````B40D$(G8
M#ZSP`XE4)!2#X#^-4`'&A`2X````@(/$$(/Z.`^/I`(``+@X````*=`#5"0@
M@_@$#X/)`@``A<!T"Z@"Q@(`#X5_`P``BU0D!(L$)(B<).<````/K-`8BU0D
M!(B$).````"+!"0/K-`0BU0D!(B$).$```"+!"0/K-`(B(0DX@````^V!"2(
MA"3C````B=@/K/`8B(0DY````(G8#ZSP$(B$).4```")V`^L\`B(A"3F````
MBT0D+.C?P/__BW0D<(M\)'2)\0^L^1B(C"3O````#[;!B?$/K/D0B(PD\```
M`(GQ#ZSY"(M\)'R(C"3Q````B?&+="1XB(PD\@```(GQ#ZSY&(B,)/,```")
M\0^L^1"(C"3T````B?$/K/D(B[PDA````(B,)/4```")\8NT)(````"(C"3V
M````B?$/K/D8B(PD]P```(GQ#ZSY$(B,)/@```")\0^L^0B+O"2,````B(PD
M^0```(GQB[0DB````(B,)/H```")\0^L^1B(C"3[````B?$/K/D0B(PD_```
M`(GQ#ZSY"(N\))0```"(C"3]````B?&+M"20````B(PD_@```(GQ#ZSY&(B,
M)/\```")\0^L^1"(C"0``0``B?$/K/D(C;PD*P$``(B,)`$!``")\8VT)/``
M``"(C"0"`0``C8PD`P$``(E,)!R)RHV-6)/__XD,)(E\)!2)]XG6Z0<```"0
M#[8'@\<!@^P,B>M0_W0D$&K_:@%6@\8"Z).[__^#Q"`Y="04==J-A:F3___&
MA"0K`0```(GK4(V%=9/___]T)"#_="08_W0D&%!J_VH!_W0D-.A9N___@\0@
MZ3_Y__^+1"0<BU`$A=(/A%KX__^#[`R)ZU*)5"0DZ&.Y__^#Q!"#^`,/AC_X
M__^+5"04C;UPD___N04```"-=`+\\Z8/110DB10DZ1[X__^+3"0@N$`````!
MT2G0B<)T#3'`Q@0!`(/``3G0<O6+1"0LZ*^^__^+?"0@N0X````QP/.KZ4;]
M__^-2@3'`@````#'1`+\`````(/A_"G*`<*#XOR#^@0/@B+]__^#XOPQP,<$
M`0````"#P`0YT'+RZ0K]__^`O"0N`0``00^%@_G__X"\)"\!``!##X5U^?__
M@+PD,`$``$@/A6?Y__^`O"0Q`0``10^%6?G__VH":O]JQHMT)"A6Z-FW__^#
MQ`QJ*8M\)!Q75NBIMO__C86ID___4(V%=9/__U?_="0H_W0D*%!J_VH!_W0D
M1.@5NO__@\0PZ?OW__^0C70F`#')9HE,`O[I=?S__^BW!```C;0F`````%57
M5E/HA[S__X'#`W,``(/L.(NK"`$``&6A%````(E$)"@QP/]U`.ATN?__7_]U
M`(G&Z&FY__\/MD!HB$9IC40D*(E$)!R)PHV#8Y+__^@-X___@\00A<!T"8`X
M,0^$?0(``.AH[O__@^P,_W4`Z"VY__^-DZ.3__]J"VH!4E#H3+?__X/$((7`
M#X2R````BT`,@[M\$0```8M`&(E$)`0/CIL````Q_[X!````ZRV0BT(,@^P(
M4(N#>!$``/\TL.B+M?__@\00A<!U9(N#?!$``(/&`8/'`3GP?EJ#[`S_=0#H
MN;C__VH`5_]T)!Q0Z#RX__^#Q""%P'0UBQ"+0@@E``0@`#T`!```=*2)5"0(
M@^P,_W4`Z(6X__]J`FH`BU0D(%)0Z":V__^#Q"#KA)"+@WP1``"-4/\Y^@^$
M7P$``(/L#/]U`.A4N/__C9.HD___:@-J`5)0Z'.V__^#Q""%P(G&=#.+0`R#
M[`R+./]U`.@JN/__C9.JD___@\0,4E=0Z+FU__^+1@R#Q!"+,/9&"D`/A;`!
M``"#[`S_=0#H_+?__XV3KY+__VH#:@%24.@;MO__@\0@A<")QG0WBU0D#(V#
M,9+__^B3X?__A<")QP^$20$``(M&#(/L#(LP_W4`Z+FW__^#Q`Q75E#H3K7_
M_X/$$(/L#/]U`.B@M___C9.OD___@\0,:@%24.@^MO__B<98_W4`Z(.W__^-
MD\23__^#Q`Q25E#H$K7__UK_=0#H:;?__XM4)!S&0&D`C8,HDO__Z!;A__^#
MQ!"%P(G&B8.`$0``#X23````@^P(:,`!``!6Z!6V__^-4`&#Q!"#^@%V"8/X
M$0^%ZP```(M$)!QE,P44````#X75````@\0L6UY?7<.0C;0F`````(/X`0^.
MF/[__XM\)`2^`0```(VV`````(/L#/]U`(/&`>C:MO__6EE74.CAL___@\00
M.;-\$0``?][I8O[__Y"`>`$`#X1^_?__Z73]__^0@^P,_[-X$0``Z-+O__^#
MQ!"%P(G&B8.`$0``#X5,____C8.0E/__@^P,4.A`M?__BX-X$0``@^P,BSB+
M1@R+,/]U`.AHMO__B?J)\.C_Y?__@\00Z:S^__^#[`S_=0#H3+;__UE?5E#H
M<[7__X/$$.DT_O__Z$8!``!0BX-X$0``5O\PC8.TE/__4.C@M/__5U93BW0D
M$.@$N?__@<.`;P``@^P,5NA%ZO__#[8(@\00A,ET2(U0`8G'C;8`````@/DO
M#[8*#T3Z@\(!A,EU\.CK[/__A?9T((7`=!R`/@!T%XV#79/__X/L"%!7Z%ZR
M__^#Q!`Y^'0(6UY?PXG'Z\];B?!>7^D5X___BRPDPY!3Z(JX__^!PP9O``"#
M[`B-@S@!``"%P'0?BP!0_W0D'/]T)!S_="0<Z$.S__^#Q!A;PXVV`````#'`
MZ]]FD&:055=64^A'N/__@</#;@``@^P,BVPD((VS\/[__^BKL?__C8/L_O__
M*<;!_@*%]G0E,?^-M@````"#[`3_="0L_W0D+%7_E+OL_O__@\<!@\00.?YU
MXX/$#%M>7UW#C78`\\-FD&:09I!FD&:09I!FD%/HVK?__X'#5FX``(/L".@L
MLO__4X/L".C#M___@<,_;@``@\0(6\,#`````0`"`"5S+R5S`"]P<F]C+W-E
M;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-
M10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%2
M7T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!0
M05)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!0
M05)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0051(`$193$1?3$E"
M4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2
M`%1-4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`"5S
M)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!
M4D=6`!@`<&5R;`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`S-@`M90`M+0!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I+F,`
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%2
M1U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q
M("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P
M?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]]
M(&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S
M=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB
M:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE
M.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I[
M"B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(
M+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G
M;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S
M970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N
M;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B
M7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]
M("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#([
M"GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T
M.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS
M965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM
M>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@
M9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?
M.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN
M960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R
M;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I
M;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY
M("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE
M;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")"
M;V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q
M(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L
M("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB
M:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*
M;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@
M)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I
M92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")0
M2UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T
M85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1?
M?2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*
M;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN
M("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E
M;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@
M)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@
M1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,
M12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C
M;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F
M:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y0
M05(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@
M9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?
M0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@
M>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ
M."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U
M9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D
M9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*
M96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R
M(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H
M.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF
M:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD
M7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*``$;`SOP````'0```#!Q__\,`0```'7_
M_S`!```0=?__N`T``,!X__]$`0``8)[__X@!```PG___[`$``,"?__\D`@``
M$*+__Z0"``"@H___7`,``$"D___,`P``$*7__V@$``!0I?__F`0``+"E___D
M!```@*;__W@%``"0IO__C`4``+"H__^(!@``X*C__YP&``#0J?__$`<``+"K
M__](!P``,*S__VP'``!PK/__F`<``-"M__\,"````+O___0+``"`OO__:`T`
M`/N^__\`#@```+___Q0.``!`O___2`X``*"___^4#@``L+___Z@.```4````
M``````%Z4@`!?`@!&PP$!(@!```@````'````!QP___0`P````X(1@X,2@\+
M=`1X`#\:.RHR)"(0````0````,AS__\0`````````$````!4````='?__Y@E
M````00X(A0)!#@R'`T0.$(8$00X4@P5&#J`&`X$E"@X40<,.$$'&#@Q!QPX(
M0<4.!$$+````8````)@```#0G/__R0````!!#@B%`D$.#(<#00X0A@1!#A2#
M!4X.,`)9#C1!#CA$#CQ!#D!(#C!7"@X40\,.$$'&#@Q!QPX(0<4.!$H+7@H.
M%$/##A!!Q@X,0<<."$'%#@1!"S0```#\````/)W__XH`````00X(AP)!#@R&
M`T,.$(,$3@X@`FX*#A!!PPX,0<8."$''#@1!"P``?````#0!``"4G?__00(`
M``!!#@B%`D$.#(<#0PX0A@1!#A2#!5`.3%<.4$@.0%D.3$,.4$@.0`)/#DQ-
M#E!(#D`">`H.%$'##A!!Q@X,0<<."$'%#@1'"P)8#DA!#DQ!#E!,#D!Q#DQ+
M#E!(#D!.#D1!#DA)#DQ%#E!0#D````"T````M`$``&2?__^&`0```$$."(4"
M00X,AP-!#A"&!$$.%(,%4PZ@`6P*#A1!PPX00<8.#$''#@A!Q0X$20M##JP!
M00ZP`4@.H`%?#JP!00ZP`4@.H`%[#JP!00ZP`6L.K`%!#J@!10ZL`4$.L`%$
M#K0!0@ZX`4(.O`%!#L`!2`ZD`40.J`%!#JP!0@ZP`4@.H`%8#JP!00ZP`4@.
MH`%##JP!00ZP`4@.H`%<#JP!00ZP`5`.H`$`;````&P"```\H/__F`````!!
M#@B'`D$.#(8#0PX0@P1.#AQ(#B!(#A1&#AA!#AQ"#B!(#A!%"L,.#$/&#@A!
MQPX$0PM##AQ"#B!.#A!/#AQ"#B!.#A!/#AA"#AQ!#B!(#A!&PPX,1,8."$''
M#@0``)@```#<`@``;*#__]``````00X(A0)!#@R'`T,.$(8$00X4@P51#L0@
M6`[(($L.S"!!#M`@2`[`(%,.Q"!!#L@@0@[,($$.T"!(#L`@30[,($(.T"!&
M#M0@00[8($$.W"!!#N`@2`[`(%8*#A1!PPX00<8.#$''#@A!Q0X$1`M1#LP@
M0@[0($@.Q"!$#L@@00[,($$.T"!(#L`@`"P```!X`P``H*#__SL`````00X(
M@P).#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"H`P``L*#__U,`````
M00X(A@)!#@R#`TX.'$@.($X.'$(.($8.'$<.&$(.'$$.($$.)$<.*$<.+$$.
M,$@.#$'##@A!Q@X$``"0````]`,``,2@___)`````$$."(4"00X,AP-!#A"&
M!$$.%(,%40ZP0%T.N$!!#KQ`00[`0$<.Q$!%#LA`0@[,0$4.T$!(#K!`1PZT
M0$4.N$!(#KQ`00[`0$@.L$!,#KQ`00[`0$@.L$!)#K1`00ZX0$$.O$!!#L!`
M3`ZP0%@*#A1!PPX00<8.#$''#@A!Q0X$2PL`$````(@$````H?__!0``````
M``#X````G`0``/R@__\=`@```$$."(4"00X,AP-!#A"&!$$.%(,%40[`('0.
MR"!$#LP@00[0($@.P"!P"@X40<,.$$'&#@Q!QPX(0<4.!$$+0P[,($0.T"!&
M#LP@00[(($T.S"!!#M`@30[`(&@.R"!!#LP@00[0($@.P"!+#LP@00[0($@.
MP"!T#L0@1`[(($$.S"!'#M`@00[4($4.V"!"#MP@10[@($@.S"!&#M`@2`[$
M($8.R"!!#LP@0@[0($@.P"!'#LP@0@[0($X.P"!/#L@@1`[,($(.T"!(#L`@
M`DD.R"!"#LP@00[0($@.P"!4#LP@00[0($@.P"`0````F`4``""B__\B````
M`````'````"L!0``/*+__^P`````00X(A@)!#@R#`TX.(%8.+$$.,$P.('@.
M+$(.,$@.($\*#@Q!PPX(0<8.!$H+80XD00XH00XL1PXP2`X@10H.#$'##@A!
MQ@X$1PM#"@X,0\,."$'&#@1!"TD.+$$.,$@.(```-````"`&``"XHO__V0$`
M``!!#@B'`D$.#(8#00X0@P1.#D`#=@$*#A!!PPX,0<8."$''#@1&"P`@````
M6`8``&"D__]Y`````$$."(,"3@X@9PH."$'##@1)"P`H````?`8``+RD__\T
M`````$$."(,"3@X02`X<00X@2`X020H."$'##@1&"W````"H!@``T*3__UH!
M````00X(A0)!#@R'`T$.$(8$00X4@P5.#G`"@0YX1`Y\00Z``4P.<`)&"@X4
M0<,.$$'&#@Q!QPX(0<4.!$(+0PY\1`Z``6P.=$4.>$0.?$0.@`%$#H0!0@Z(
M`4(.C`%!#I`!3`YPY`,``!P'``"\I?__*0T```!!#@B%`D$.#(<#00X0A@1!
M#A2#!5$.T(("`L(.W(("0P[@@@)8#M""`EP.W(("1@[@@@)$#N2"`D(.Z(("
M0@[L@@)!#O""`DL.T(("?P[<@@)##N""`D@.T((";`[<@@)!#N""`DH.T(("
M5`[<@@)##N""`D@.T(("?P[<@@)(#N""`E4.Y(("00[H@@)+#NR"`D<.\(("
M0P[T@@)"#OB"`D(._(("00Z`@P)(#MB"`D4.W(("00[@@@)(#M""`E(.W(("
M1`[@@@)(#M2"`D8.V(("1`[<@@)"#N""`DP.T(("2P[<@@)&#N""`D8.Y(("
M1P[H@@)(#NR"`D(.\(("2`[0@@)F"@X40<,.$$'&#@Q!QPX(0<4.!$L+4P[8
M@@)!#MR"`D0.X(("1@[D@@)'#NB"`D@.[(("0@[P@@)(#M""`E0.W(("0@[@
M@@).#M""`E,.W(("0@[@@@)7#M""`DP.W(("0@[@@@).#M""`E,.W(("0P[@
M@@);#M""`DL.W(("0P[@@@)&#MR"`D$.V(("00[<@@)&#N""`DP.T(("2P[<
M@@)'#N""`D@.T(("?@[8@@)$#MR"`D0.X(("3`[0@@)M#M2"`D$.V(("2@[<
M@@)$#N""`D$.Y(("0@[H@@)"#NR"`D0.\(("2`[0@@)R#MR"`D0.X(("00[D
M@@)!#NB"`D0.[(("1`[P@@)$#O2"`D(.^(("0@[\@@)!#H"#`D@.T(("0P[8
M@@)'#MR"`D$.X(("2`[0@@)(#MR"`D8.X(("80[0@@)+#MR"`D,.X(("7`[0
M@@)T#MR"`D,.X(("2`[0@@).#MR"`DH.X(("3`[0@@);#M2"`D(.V(("0@[<
M@@)%#N""`D@.U(("0@[8@@),#MR"`D$.X(("2`[0@@):#M2"`D(.V(("1`[<
M@@)$#N""`@*M#M""`EH.U(("10[8@@)$#MR"`D0.X(("3`[0@@("E@[4@@)!
M#MB"`D0.W(("00[@@@)<#M""`@,/`0[4@@)!#MB"`D$.W(("1`[@@@)3#M""
M`GL.W(("1`[@@@("0@[0@@(##`(.W(("0P[@@@)$#N2"`D(.Z(("0@[L@@)!
M#O""`DL.T(("5P[4@@)*#MB"`D0.W(("1`[@@@)!#N2"`D(.Z(("0@[L@@)$
M#O""`D@.T(("5P[<@@)##N""`DP.T(("`MD.U(("0@[8@@)"#MR"`D4.X(("
M2`[4@@)"#MB"`D4.W(("00[@@@),#N2"`D<.Z(("1`[L@@)$#O""`D$.](("
M0@[X@@)"#OR"`D0.@(,"2`[0@@(``'`!```$"P``!*___X`#````00X(A0)!
M#@R'`T$.$(8$00X4@P5.#DQ5#E!&#DQ##E!F#D!5#DQ##E!-#E1"#EA!#EQ!
M#F!(#D!O#DA!#DQ)#E!(#D!7#DQ##E!'#E1!#EA$#EQ!#F!(#D!<#DQ##E!'
M#E1"#EA%#EQ!#F!(#D!7#DQ##E!-#E1"#EA!#EQ!#F!(#D!,#DQ%#E!.#D1!
M#DA!#DQ!#E!+#D!/#DQ##E!-#E1"#EA!#EQ!#F!(#D!E#DQ%#E!(#D1!#DA!
M#DQ!#E!(#D!##DQ##E!.#D1"#DA!#DQ!#E!(#DQ##E!.#D1!#DA!#DQ!#E!&
M#DQ##E!;#D!3#DA%#DQ!#E!+#D!B"@X40<,.$$'&#@Q!QPX(0<4.!$D+6PY,
M0PY020Y,00Y(00Y,00Y02`Y`80H.3$8.4$@.0%D.3$$.4$4+20Y,2@Y040Y`
M2`Y,0PY01@Y,00Y(00Y,00Y02`Y`2PY$1PY(0@Y,1PY0`$P```!X#```$+'_
M_WL`````00X(AP)!#@R&`T$.$(,$4@X<00X@2PX0>@X800X<00X@2`X010K#
M#@Q!Q@X(0<<.!$$+1<,.#$/&#@A!QPX$1````,@,``!09___0`(```!$#`$`
M1Q`%`G4`1@\#=7`&$`<"=7P0!@)U>!`#`G5T`WL!"L$,`0!!PT'&0<=!Q4,,
M!`1!"P``$````!`-``#SL/__!``````````P````)`T``.2P__\\`````$$.
M"(,"3@X030X41`X81`X<1`X@2`X(0<,.!$<.$(,"````2````%@-``#PL/__
M70````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.(&D.)$0.*$0.+$$.,$T.($<.
M%$'##A!!Q@X,0<<."$'%#@0``!````"D#0``!+'__P(`````````&````+@-
M````L?__%`````!!#@B#`DX.$```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$`9``#P&`````````$````!`````0```-\!```!````
M+@(```P```#,$0``#0```(1@```9````N,T``!L````$````&@```+S-```<
M````!````/7^_V^L`0``!0```/P(```&````C`(```H```#O!```"P```!``
M```5``````````,```#,S@```@```.`!```4````$0```!<```#L#P``$0``
M`%P/```2````D````!,````(````'@````@```#[__]O`0``"/[__V^\#@``
M____;P(```#P__]O[`T``/K__V\%````````````````````````````````
M`````````````````````````,3-``````````````82```6$@``)A(``#82
M``!&$@``5A(``&82``!V$@``AA(``)82``"F$@``MA(``,82``#6$@``YA(`
M`/82```&$P``%A,``"83```V$P``1A,``%83``!F$P``=A,``(83``"6$P``
MIA,``+83``#&$P``UA,``.83``#V$P``!A0``!84```F%```-A0``$84``!6
M%```9A0``'84``"&%```EA0``*84``"V%```QA0``-84``#F%```]A0```85
M```6%0``)A4``#85``!&%0``5A4``&85``!V%0``AA4``)85``"F%0``MA4`
M`````````````````````````````````````````````````-`5````````
M``````````````````````30``#_____Q&,``$=#0SH@*%5B=6YT=2`V+C0N
M,"TR=6)U;G1U,2D@-BXT+C`@,C`Q-S`W,C0`1T-#.B`H56)U;G1U(#8N-"XP
M+3%U8G5N='4R*2`V+C0N,"`R,#$W,#<P-```+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````
M``````````````````````````````````````````````````````L````!
M`````@```%0!``!4`0``$P```````````````0`````````3````!P````(`
M``!H`0``:`$``"````````````````0`````````(0````<````"````B`$`
M`(@!```D```````````````$`````````#0```#V__]O`@```*P!``"L`0``
MX`````4`````````!`````0````^````"P````(```",`@``C`(``'`&```&
M`````0````0````0````1@````,````"````_`@``/P(``#O!```````````
M```!`````````$X```#___]O`@```.P-``#L#0``S@````4``````````@``
M``(```!;````_O__;P(```"\#@``O`X``*`````&`````@````0`````````
M:@````D````"````7`\``%P/``"0````!0`````````$````"````',````)
M````0@```.P/``#L#P``X`$```4````7````!`````@```!\`````0````8`
M``#,$0``S!$``",```````````````0`````````=P````$````&````\!$`
M`/`1``#0`P`````````````0````!````((````!````!@```,`5``#`%0``
M$```````````````"`````@```"+`````0````8```#0%0``T!4``+1*````
M`````````!``````````D0````$````&````A&```(1@```4````````````
M```$`````````)<````!`````@```)A@``"88```*$``````````````!```
M``````"?`````0````(```#`H```P*```/0```````````````0`````````
MK0````$````"````M*$``+2A``#4#0`````````````$`````````+<````.
M`````P```+C-``"XO0``!```````````````!`````0```##````#P````,`
M``"\S0``O+T```0```````````````0````$````SP````$````#````P,T`
M`,"]```$```````````````$`````````-0````&`````P```,3-``#$O0``
M"`$```8`````````!`````@```"&`````0````,```#,S@``S+X``#0!````
M``````````0````$````W0````$````#`````-````#````0````````````
M```$`````````.,````(`````P```"#0```0P```-!``````````````(```
M``````#H`````0```#``````````$,```%@```````````````$````!````
H`0````,``````````````&C```#Q```````````````!````````````
